# SaaS Discovery Inbox
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/saas-discovery-inbox#introduction)
  * [Accessing SaaS Discovery Inbox](https://help.sap.com/docs/leanix/ea/saas-discovery-inbox#accessing-saas-discovery-inbox)
  * [List of Discovered SaaS Applications](https://help.sap.com/docs/leanix/ea/saas-discovery-inbox#list-of-discovered-saas-applications)
  * [Automatic Linking of Discovered Applications to Fact Sheets](https://help.sap.com/docs/leanix/ea/saas-discovery-inbox#automatic-linking-of-discovered-applications-to-fact-sheets)
  * [Manual Linking of Discovered Applications to Fact Sheets](https://help.sap.com/docs/leanix/ea/saas-discovery-inbox#manual-linking-of-discovered-applications-to-fact-sheets)
  * [Rejecting Discovered Items](https://help.sap.com/docs/leanix/ea/saas-discovery-inbox#rejecting-discovered-items)
  * [Linking / Rejecting Multiple Items at Once](https://help.sap.com/docs/leanix/ea/saas-discovery-inbox#linking-/-rejecting-multiple-items-at-once)
  * [Modifying the Established Link](https://help.sap.com/docs/leanix/ea/saas-discovery-inbox#modifying-the-established-link)


View all
Discovered SaaS applications are listed in the SaaS discovery inbox. Learn how to link the discovered items to fact sheets or review and reject them as needed.
